Module variable

Module variable 

A Variable is the base element used to create an Expression. The goal of the solver is to find optimal values for all variables in a problem.

Each variable has a VariableDefinition that sets its bounds.

Structs

ProblemVariables
Represents the variables for a given problem. Each problem has a unique type, which prevents using the variables from one problem inside an other one. Instances of this type should be created exclusively using the crate::variables! macro.
UnsolvedProblem
A problem without constraints. Created with ProblemVariables::optimise.
Variable
A variable in a problem. Use variables to create expressions, to express the objective and the Constraints of your model.
VariableDefinition
Defines the properties of a variable, such as its lower and upper bounds.

Traits

FormatWithVars
An element that can be displayed if you give a variable display function

Functions

variable
Returns an anonymous unbounded continuous variable definition