Variable

Struct Variable 

pub struct Variable { /* private fields */ }
A variable in a problem. Use variables to create expressions, to express the objective and the Constraints of your model.

Variables are created using ProblemVariables::add. They implement std::ops basic math operations on f64 and i32 values.

Warning

Eq is implemented on this type, but v1 == v2 is true only if the two variables represent the same object, not if they have the same definition.

let mut vars = variables!();
let v1 = vars.add(variable().min(1).max(8));
let v2 = vars.add(variable().min(1).max(8));
assert_ne!(v1, v2);

let v1_copy = v1;
assert_eq!(v1, v1_copy);